@@ -230,10 +230,10 @@ class attributes:
                                                                                      self.y_bounds)
 
             if self.demo_pad_plot is True:
-                pad_x = 0.05 * (abs(self.x.max()) + abs(self.x.min()))
+                pad_x = 0.05 * (abs(self.x+self.x.min()).max() - abs(self.x+self.x.min()).min())
                 self.x_upper_resize_pad = pad_x
                 self.x_lower_resize_pad = pad_x
-                pad_y = 0.05 * (abs(self.y.max()) + abs(self.y.min()))
+                pad_y = 0.05 * (abs(self.y+self.y.min()).max() - abs(self.y+self.y.min()).min())
                 self.y_upper_resize_pad = pad_y
                 self.y_lower_resize_pad = pad_y
 
@@ -1209,7 +1209,7 @@ class fill_area(plot, std_input):
                                      alpha=self.alpha, label=self.plot_label)
             if self.between is False and self.below is False and self.above is False:
                 print_color('No area chosen to fill: specify whether to fill "between", "below" or "above" the curves',
-                            'blue')
+                            'grey')
         else:
             self.ax.fill_between(self.x, self.y, np.zeros(self.y.shape), facecolor=self.color, alpha=self.alpha)
 
